import React, { useEffect, useState } from 'react';
import { DrawerContentScrollView, DrawerItem } from '@react-navigation/drawer'
import Text from '../Text/Text';
import { FontAwesome } from '@expo/vector-icons';
import UserService from "../../services/UsersService"
import { colors, fonts } from '../../config/Theme';
import * as s from './styles';
import { UserModel } from '../../interfaces/UserModel/UserModel.interface';
import { userScreens, authUserScreens, commonScreens } from '../../pages/Router';
import {
	Screens,
	userSection,
	commonSection,
	authUserSection,
} from '../../interfaces/NavigationProps/NavigationProps.interface';

export default function DrawerContent(props : any) {

	const { navigation } = props;
	const [ isAuth, setIsAuth ] = useState(false);
	const [ user, setUser ] = useState<UserModel | null>(null);

	async function setUp() {
		if (!UserService.user) {
			await UserService.loadUser();
		}
		if (UserService.user) {
			setIsAuth(true);
			setUser(UserService.user);
		}
		else{
			setIsAuth(false);
			setUser(null);
		}
	}

	useEffect(() => {
		setUp()
	}, [UserService.user]);

	const handleLogoffPress = async () => {
		await UserService.logout()
		setIsAuth(false);
		setUser(null);
	};

	const buildDrawerItem = (screens: userSection | authUserSection | commonSection ) => {
		return (
			Object.entries(screens).map(([name, { label, component }]) => (
				<DrawerItem
					key={name}
					label={label}
					onPress={() => { component() ? navigation.navigate(name) : null }}
					{...drawerItemProps}
				/>
			)));
	}

	const drawerItemProps = {
		...props,
		activeTintColor: 'rgba(0, 0, 0, 0.08);',
		activeBackgroundColor: 'rgba(0, 0, 0, 0.08);',
		labelStyle: { color: colors.white, fontSize: 20, fontFamily: fonts.bold }
	}

	return (
		<s.Container>
			<s.Header>
				{isAuth ?
				<>
					<s.ViewUser>
						<FontAwesome name="user-circle-o" size={50} color="white"/>
						<s.ViewUserText>
							<Text color="white" fontWeight="bold">
								{`${user?.givenName} ${user?.familyName}`}
							</Text>
							<s.ButtonAccount>
								<Text color="white">
									Minha Conta
								</Text>
							</s.ButtonAccount>
							<s.ButtonLogoff>
								<Text color="red" onPress={() =>  handleLogoffPress() }>
									Logoff
								</Text>
							</s.ButtonLogoff>
						</s.ViewUserText>
					</s.ViewUser>
				</>
				:
				<>
					<Text color="white" marginBottom="50px">
						Entre para ver seus <Text color="white" fontWeight="bold">favoritos, reservar um espaço e visualizar seus locais</Text>.
					</Text>
					<s.BlankLine/>
					<s.ButtonLogin borderColor='white' onPress={() => { navigation.navigate(Screens.Login) }}>
						Entrar
					</s.ButtonLogin>
				</>
				}
			</s.Header>

			<s.Line/>

			<DrawerContentScrollView>
				{
					buildDrawerItem({
						...userScreens,
						...(isAuth ? authUserScreens : {}),
						...commonScreens
					})
				}
			</DrawerContentScrollView>
		</s.Container>
	);
}
