import React, { useRef, useState } from "react";
import { Formik, FormikProps } from "formik";
import { Platform } from "react-native";
import { ScrollView } from "react-native-gesture-handler";
import {
	KeyboardAvoidingView,
	FormContainer,
	InputContainer,
	MessageError,
	Footer,
	TextInput,
	TextInputContainer,
	FirebaseMessage,
	TextInputMessage,
} from "./styles";
import { FormSchema } from "./FormSchema";
import {
	InitialValues,
	ContactModel,
} from "../../interfaces/ContactModel/ContactModel.interface";
import Title from "../../components/Title/Title";
import Button from "../../components/Button/Button";
import ContactsService from "../../services/ContactsService";
import { ContactPageProps } from "../../interfaces/ContactPageProps/ContactPageProps";

const Contact: React.FC<ContactPageProps> = ({ navigation, route }) => {
	const fullName = useRef(null);
	const email = useRef(null);
	const phoneNumber = useRef(null);
	const message = useRef(null);
	const [firebaseMessage, setFirebaseMessage] = useState("");
	const [isFirebaseSuccess, setFirebaseSuccess] = useState(false);
	const [isLoading, setIsLoading] = useState(false)

	const submitContact = async (values: ContactModel) => {
		const payload: ContactModel = {
			fullName: values.fullName,
			email: values.email,
			phoneNumber: values.phoneNumber,
			message: values.message + "\n\n" + values.header,
			extra: values.extra,
			type: values.type || 'home'
		};


		setIsLoading(true)

		ContactsService.sendContact(payload)
			.then(() => {
				setFirebaseMessage("Mensagem enviada!");
				setFirebaseSuccess(true);
			})
			.catch((error) => {
				setFirebaseMessage("Erro ao enviar a mensagem.");
				setFirebaseSuccess(false);
			})
			.finally(() => setIsLoading(false))
	};

	return (
		<KeyboardAvoidingView
			behavior={Platform.OS == "ios" ? "padding" : "height"}
		>
			<Formik
				initialValues={route?.params?.specs || InitialValues}
				validationSchema={FormSchema}
				onSubmit={(values) => submitContact(values)}
			>
				{({
					values,
					handleChange,
					handleSubmit,
					errors,
					touched,
					setFieldTouched,
					isValid,
				}: FormikProps<ContactModel>) => {
					return (
						<ScrollView>
							<FormContainer>
								<Title>Entre em Contato</Title>
								<InputContainer>
									<TextInputContainer>
										<TextInput
											_ref={fullName}
											value={values.fullName}
											placeholder="Nome completo"
											onChangeText={handleChange("fullName")}
											onBlur={() => setFieldTouched("fullName", true)}
										/>
										{errors.fullName && touched.fullName && (
											<MessageError>{errors.fullName}</MessageError>
										)}
									</TextInputContainer>

									<TextInputContainer>
										<TextInput
											_ref={email}
											value={values.email}
											keyboardType="email-address"
											placeholder="E-mail"
											textContentType="emailAddress"
											onChangeText={handleChange("email")}
											onBlur={() => setFieldTouched("email", true)}
										/>
										{errors.email && touched.email && (
											<MessageError>{errors.email}</MessageError>
										)}
									</TextInputContainer>

									<TextInputContainer>
										<TextInput
											_ref={phoneNumber}
											value={values.phoneNumber}
											keyboardType="phone-pad"
											placeholder="Telefone"
											textContentType="telephoneNumber"
											onChangeText={handleChange("phoneNumber")}
											onBlur={() => setFieldTouched("phoneNumber", true)}
										/>
										{errors.phoneNumber && touched.phoneNumber && (
											<MessageError>{errors.phoneNumber}</MessageError>
										)}
									</TextInputContainer>

									<TextInputContainer>
										<TextInputMessage
											_ref={message}
											textAlignVertical={"top"}
											multiline={true}
											numberOfLines={6}
											value={values.message}
											placeholder="Mensagem"
											onChangeText={handleChange("message")}
											onBlur={() => setFieldTouched("message", true)}
										/>
										{errors.message && touched.message && (
											<MessageError>{errors.message}</MessageError>
										)}
									</TextInputContainer>
								</InputContainer>
								<Footer>
									<Button
										loading={isLoading}
										testID="btnSendMessage"
										onPress={handleSubmit}
										disabled={!isValid}
									>
										Enviar Mensagem
									</Button>
								</Footer>
								<Footer>
									<FirebaseMessage success={isFirebaseSuccess}>
										{firebaseMessage}
									</FirebaseMessage>
								</Footer>
							</FormContainer>
						</ScrollView>
					);
				}}
			</Formik>
		</KeyboardAvoidingView>
	);
};

export default Contact;
