import React, { useEffect, useState } from 'react';
import { ScrollView, Modal, TouchableOpacity } from 'react-native';
import Place from '../../components/Place/Place';
import { CityName, SafeAreaColor, ViewFilterButton, Container, ModalView, ModalContainer, SpacedText, ModalText, CenteredView, ModalFooter } from './styles';
import Button from '../../components/Button/Button';
import Text from '../../components/Text/Text';
import FilterButton from '../../components/FilterButton/FilterButton';
import { PlaceModel } from '../../interfaces/PlaceModel/PlaceModel.interface';
import { SearchParams, InitialValues } from '../../interfaces/SearchParams/SearchParams.interface';
import PlacesService from '../../services/PlacesService';
import Loading from "../../components/Loading/Loading";
import { MaterialIcons } from '@expo/vector-icons';
import { ListPlacesPageProps } from '../../interfaces/ListPlacesPageProps/ListPlacesPageProps.interface';
import { SearchFilterFormField } from "../../interfaces/SearchFilterFormProps/SearchFilterFormProps.interface";
import SearchFilterForm from '../../components/SearchFilterForm/SearchFilterForm';

import { Screens } from '../../interfaces/NavigationProps/NavigationProps.interface';
import UtilsService from '../../services/UtilsService';

const ListPlaces: React.FC<ListPlacesPageProps> = ({ navigation, route }) => {

	const [inputQuery, setInputs] = useState([] as PlaceModel[]);
	const [modalVisible, setModalVisible] = useState(false);
	const [loading, setLoading] = useState(false);

	const [params, setParams] = useState(InitialValues);

	function handleChangeField({ name, value }: SearchFilterFormField) {
		setParams({ ...params, [name]: value });
	}

	async function searchPlaces(_params?: SearchParams) {
		setModalVisible(false);
		setLoading(true);

		let list = await PlacesService.searchPlaces(_params || params);

		console.log('list :>> ', list);

		setInputs(list);
		setLoading(false);
	}

	useEffect(() => {
		if (route?.params?.specs) {
			const _params: SearchParams = route.params.specs;
			setParams(_params)
			searchPlaces(_params)
		}
	}, []);

	const clearModal = async () => {
		setParams(InitialValues)
		setModalVisible(false);
	};

	return (
		<SafeAreaColor>
			<ScrollView contentContainerStyle={{ flexGrow: 1 }}>
				<Container>
					<Modal
						animationType="slide"
						transparent={true}
						visible={modalVisible}
					>
						<CenteredView>
							<ModalView>
								<SpacedText>
									<ModalText>
										Filtros
									</ModalText>
									<TouchableOpacity onPress={() => clearModal()}>
										<MaterialIcons name="close" size={20} color="black" />
									</TouchableOpacity>
								</SpacedText>
								<ModalContainer>
									<SearchFilterForm
										searchParams={params}
										onChangeField={handleChangeField}
									/>
									<ModalFooter>
										<Button onPress={() => searchPlaces()}>Filtrar</Button>
									</ModalFooter>
								</ModalContainer>
							</ModalView>
						</CenteredView>
					</Modal>

					<ViewFilterButton>
						<CityName>
							{params?.city?.name || ""}
						</CityName>
						<FilterButton width='110px' onPress={() => setModalVisible(true)}>
							Filtros
					</FilterButton>
					</ViewFilterButton>
					{loading && <Loading />}
					{!loading && <>{inputQuery?.length ? inputQuery.map((item, index) => (
						<Place
							key={index}
							spaceId={item.spaceId}
							title={item.title}
							address={item.address}
							capacity={item.capacity}
							size={item.size}
							price={UtilsService.getPrice(item)}
							onPress={(imageURL) => {
								navigation.navigate(Screens.PlaceDetails, { specs: { ...inputQuery[index], imageURL, spaceId: item.spaceId }, search: route?.params?.specs })
							}}
						/>
					)) :
						<CenteredView>
							<Text>Ops! Nenhum local encontrado :(</Text>
						</CenteredView>
					}</>}
				</Container>
			</ScrollView>
		</SafeAreaColor>
	);
}

export default ListPlaces;
