import React, { useRef, useState, useEffect } from "react";
import { Dimensions } from "react-native";
import { ScrollView, TouchableOpacity } from "react-native-gesture-handler";
import Text from "../../components/Text/Text";
import {
	ContainerLogin,
	TextInput,
	LineSeparator,
	ButtonContainer,
	HaveAccountText,
	stylesPhoneInput,
	ErrorMessages,
	FooterContainer,
	TextFooter,
} from "./styles";
import PhoneInput from "react-native-phone-number-input";
import { Formik, FormikProps } from "formik";
import {
	initialValues,
	IRegisterUser,
} from "../../interfaces/RegisterUser/RegisterUser.interface";
import { RegisterUserSchema } from "./RegisterUserSchema";
import { SafeAreaView } from "react-native-safe-area-context";
import UsersService from "../../services/UsersService";
import Title from "../../components/Title/Title";
import Button from "../../components/Button/Button";
import ButtonGoogle from "../../components/ButtonGoogle/ButtonGoogle";
import { Screens } from "../../interfaces/NavigationProps/NavigationProps.interface";

const screenHeight = Dimensions.get("window").height;

export default function RegisterUser({ navigation }: any) {
	const givenName = useRef(null);
	const familyName = useRef(null);
	const email = useRef(null);
	const password = useRef(null);
	const confirmPassword = useRef(null);

	const phoneInput = useRef<PhoneInput>(null);
	const [loading, setLoading] = useState(false);
	const [phone, setPhoneNumber] = useState("");
	const [formattedValue, setFormattedValue] = useState("");
	const [terms, setTerm] = useState("v1");

	const submitCreateAccount = async (values: IRegisterUser) => {
		try {
			setLoading(true);
			if (values) {
				await UsersService.registerUser({ ...values, phone: formattedValue, terms });
				setLoading(false);
				navigation.navigate(Screens.Home)
			}
		} catch (error) {
			console.log('error :>> ', error);
			setLoading(false);
		}
	};

	return (
		<SafeAreaView style={{ flexGrow: 1, backgroundColor: '#fff' }}>
			<ScrollView contentContainerStyle={{ flexGrow: 1, backgroundColor: '#fff' }}>
				<Formik
					initialValues={initialValues}
					validationSchema={RegisterUserSchema}
					onSubmit={(values) => submitCreateAccount(values)}
					enableReinitialize
				>
					{({
						values,
						handleChange,
						handleSubmit,
						errors,
						touched,
						setFieldTouched,
						isValid,
					}: FormikProps<IRegisterUser>) => {
						return (
							<>
								<ContainerLogin>
									<Title style={{ alignSelf: 'flex-start', marginBottom: 15 }}>Crie uma conta</Title>
									<TextInput
										_ref={givenName}
										keyboardType="default"
										placeholder="Digite o seu nome"
										value={values.givenName}
										onChangeText={handleChange("givenName")}
										onBlur={() => setFieldTouched("givenName", true)}
									/>

									{errors.givenName && touched.givenName && (
										<ErrorMessages fontSize="13px">{errors.givenName}</ErrorMessages>
									)}
									<TextInput
										_ref={familyName}
										placeholder="Digite o seu sobrenome"
										keyboardType="default"
										value={values.familyName}
										onChangeText={handleChange("familyName")}
										onBlur={() => setFieldTouched("familyName", true)}
									/>

									{errors.familyName && touched.familyName && (
										<ErrorMessages fontSize="13px">
											{errors.familyName}
										</ErrorMessages>
									)}

									<TextInput
										_ref={email}
										placeholder="Digite o seu e-mail"
										keyboardType="email-address"
										value={values.email}
										onChangeText={handleChange("email")}
										onBlur={() => setFieldTouched("email", true)}
									/>

									{
										errors.email && touched.email && (
											<ErrorMessages fontSize="13px">
												{errors.email}
											</ErrorMessages>
										)
									}

									<PhoneInput
										textInputStyle={stylesPhoneInput.textInputStyle}
										codeTextStyle={stylesPhoneInput.codeTextStyle}
										textContainerStyle={stylesPhoneInput.textContainerStyle}
										containerStyle={stylesPhoneInput.containerStyle}
										countryPickerProps={{filterProps: {placeholder: 'Digite o nome do país'}}}
										ref={phoneInput}
										defaultValue={phone}
										defaultCode="BR"
										onChangeText={(text) => {
											setPhoneNumber(text);
										}}
										onChangeFormattedText={(text) => {
											setFormattedValue(text);
										}}
										placeholder="51999999999"
									/>

									{/* {errors.phoneNumber && touched.phoneNumber && (
									<ErrorMessages fontSize="13px">
										{errors.phoneNumber}
									</ErrorMessages>
									)} */}

									<TextInput
										_ref={password}
										placeholder="Senha"
										keyboardType="default"
										secureTextEntry
										value={values.password}
										onChangeText={handleChange("password")}
										onBlur={() => setFieldTouched("password", true)}
									/>

									{
										errors.password && touched.password && (
											<ErrorMessages fontSize="13px">
												{errors.password}
											</ErrorMessages>
										)
									}

									<TextInput
										_ref={confirmPassword}
										placeholder="Confirme a senha"
										value={values.confirmPassword}
										keyboardType="default"
										secureTextEntry
										onChangeText={handleChange("confirmPassword")}
										onBlur={() => setFieldTouched("confirmPassword", true)}
									/>

									{
										errors.confirmPassword && touched.confirmPassword && (
											<ErrorMessages fontSize="13px">
												{errors.confirmPassword}
											</ErrorMessages>
										)
									}

									<Text style={{ marginBottom: 20, marginTop: 20 }} textAlign="center">
										Ao clicar em CRIAR CONTA, você estará concordando
										automaticamente com os termos de uso e a política de
										privacidade
									</Text>

									<Button onPress={handleSubmit} loading={loading} disabled={!isValid}>
										Criar conta
									</Button>

									<ButtonContainer>
										<TouchableOpacity
											onPress={() => {
												navigation.navigate(Screens.Login);
											}}
										>
											<HaveAccountText fontSize="18px" textAlign="center">
												Tenho uma conta
											</HaveAccountText>
										</TouchableOpacity>
									</ButtonContainer>

									<LineSeparator />

									<ButtonGoogle />

									<FooterContainer>
										<TouchableOpacity
											onPress={() => {
												navigation.navigate(Screens.TermsOfUse);
											}}
										>
											<TextFooter>Termos de Uso</TextFooter>
										</TouchableOpacity>
										<TextFooter> | </TextFooter>
										<TouchableOpacity
											onPress={() => {
												navigation.navigate(Screens.PrivacyPolicy);
											}}
										>
											<TextFooter>Política de privacidade</TextFooter>
										</TouchableOpacity>
									</FooterContainer>
								</ContainerLogin>
							</>
						);
					}}
				</Formik>
			</ScrollView >
		</SafeAreaView >
	);
}
