import Firebase, { firestore, storage } from "../firebase/Firebase";
import { PlaceModel } from "../interfaces/PlaceModel/PlaceModel.interface";
import { SearchParams } from "../interfaces/SearchParams/SearchParams.interface";

class PlacesService {

	/*
	// Creates a filter to be used on "listing" type objects
	// @param specs, the filter parameters to be used
	*/
	private filterCreator = (specs: SearchParams) => {
		const listingCollection = firestore.collection("listing");
		const visFilter = listingCollection.where("visibility", "==", true);
		const cityFilter = specs.city?.name
			? visFilter.where("city.name", "==", specs.city.name)
			: visFilter;
		const typeFilter = specs.place?.id
			? cityFilter.where("type", "==", specs.place.id)
			: cityFilter;
		const capFilter = typeFilter.where("capacity", ">=", +specs.people);
		const orderedFilter = capFilter.orderBy("capacity", "asc");
		//const finalFilter = orderedFilter.startAt(specs.date);
		//return finalFilter.limit(20);
		return orderedFilter.limit(20);
	};

	/*
	// Retrieves higher resolution images from firebase storage
	// @param id, the id of the space object
	*/
	public async retrievePictures(id: string) {
		const pictures = await storage
			.ref("spaces/" + id + "/photos/")
			.listAll()
			.then(async (results) => {
				let urls: string[] = [];
				for (let i = 0; i < results.items.length; i++) {
					await results.items[i].getDownloadURL().then((url) => {
						urls.push(url);
					});
				}
				return urls;
			});
		return pictures;
	};

	/*
	// Retrieves thumbnail images from firebase storage
	// @param id, the id of the space object
	*/
	public async retrieveThumbnailsItems(id: string) {
		const thumbnails = await storage
			.ref("spaces/" + id + "/photos/thumbnail/")
			.listAll()
			.then((results) => results);
		return thumbnails;
	};

	/*
	// Retrieves a filtered list of listing objects
	// @param values, the filter parameters to be used
	*/
	public async searchPlaces(values: SearchParams) {
		const filter = this.filterCreator(values);
		const list = await filter.get().then((items) => {
			const docs = items.docs;
			let result: PlaceModel[] = [];
			for (let i = 0; i < docs.length; i++) {
				const rawData = docs[i].data();
				const place: PlaceModel = {
					address: rawData.address,
					capacity: rawData.capacity,
					city: rawData.city,
					location: rawData.location,
					description: rawData.description,
					manager: rawData.manager,
					rate: rawData.rate,
					rateType: rawData.rateType,
					shortDescription: rawData.shortDescription,
					size: rawData.size,
					spaceId: rawData.spaceId,
					title: rawData.title,
					type: rawData.type,
					visibility: rawData.visibility,
					imageURL: [],
				};
				result.push(place);
			}
			return result;
		});

		return list;
	}
}
export default new PlacesService();
